@@ -1,5 +1,5 @@
 """
-**emlib** is a set of modules with miscelaneous functionality:
+**emlib** is a set of modules with miscellaneous functionality:
 
 Repository: https://github.com/gesellkammer/emlib
 
